==> oceanbase-client-2.4.0-sources.jar: com/oceanbase/jdbc/internal/logging/LoggerFactory.java <==
/**
 *  OceanBase Client for Java
 *
 *  Copyright (c) 2012-2014 Monty Program Ab.
 *  Copyright (c) 2015-2020 MariaDB Corporation Ab.
 *  Copyright (c) 2021 OceanBase.
 *
 *  This library is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU Lesser General Public License as published by the Free
 *  Software Foundation; either version 2.1 of the License, or (at your option)
 *  any later version.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 *  for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License along
 *  with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 *  This particular MariaDB Client for Java file is work
 *  derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 *  the following copyright and notice provisions:
 *
 *  Copyright (c) 2009-2011, Marcus Eriksson
 *
 *  Redistribution and use in source and binary forms, with or without modification,
 *  are permitted provided that the following conditions are met:
 *  Redistributions of source code must retain the above copyright notice, this list
 *  of conditions and the following disclaimer.
 *
 *  Redistributions in binary form must reproduce the above copyright notice, this
 *  list of conditions and the following disclaimer in the documentation and/or
 *  other materials provided with the distribution.
 *
 *  Neither the name of the driver nor the names of its contributors may not be
 *  used to endorse or promote products derived from this software without specific
 *  prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 *  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 *  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 *  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 *  OF SUCH DAMAGE.
 */
package com.oceanbase.jdbc.internal.logging;

public class LoggerFactory {

    private static final Logger NO_LOGGER = new NoLogger();
    private static Boolean      hasToLog  = null;

    /**
     * Initialize factory.
     *
     * @param mustLog indicate if must initiate Slf4j log
     */
    @SuppressWarnings("unchecked")
    public static void init(boolean mustLog) {
        if ((hasToLog == null || hasToLog != mustLog) && mustLog) {
            synchronized (LoggerFactory.class) {
                if (hasToLog == null || hasToLog != mustLog) {
                    try {
                        Class.forName("org.slf4j.LoggerFactory");
                        hasToLog = Boolean.TRUE;
                    } catch (ClassNotFoundException classNotFound) {
                        System.out.println("Logging cannot be activated, missing slf4j dependency");
                        hasToLog = Boolean.FALSE;
                    }
                }
            }
        }
    }

    /**
     * Initialize logger.
     *
     * @param clazz initiator class
     * @return logger
     */
    public static Logger getLogger(Class<?> clazz) {
        if (hasToLog != null && hasToLog) {
            return new Slf4JLogger(org.slf4j.LoggerFactory.getLogger(clazz));
        } else {
            return NO_LOGGER;
        }
    }
}

==> oceanbase-client-2.4.11-sources.jar: com/oceanbase/jdbc/internal/logging/LoggerFactory.java <==
/**
 *  OceanBase Client for Java
 *
 *  Copyright (c) 2012-2014 Monty Program Ab.
 *  Copyright (c) 2015-2020 MariaDB Corporation Ab.
 *  Copyright (c) 2021 OceanBase.
 *
 *  This library is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU Lesser General Public License as published by the Free
 *  Software Foundation; either version 2.1 of the License, or (at your option)
 *  any later version.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 *  for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License along
 *  with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 *  This particular MariaDB Client for Java file is work
 *  derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 *  the following copyright and notice provisions:
 *
 *  Copyright (c) 2009-2011, Marcus Eriksson
 *
 *  Redistribution and use in source and binary forms, with or without modification,
 *  are permitted provided that the following conditions are met:
 *  Redistributions of source code must retain the above copyright notice, this list
 *  of conditions and the following disclaimer.
 *
 *  Redistributions in binary form must reproduce the above copyright notice, this
 *  list of conditions and the following disclaimer in the documentation and/or
 *  other materials provided with the distribution.
 *
 *  Neither the name of the driver nor the names of its contributors may not be
 *  used to endorse or promote products derived from this software without specific
 *  prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 *  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 *  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 *  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 *  OF SUCH DAMAGE.
 */
package com.oceanbase.jdbc.internal.logging;

public class LoggerFactory {

    private static final Logger NO_LOGGER    = new NoLogger();
    private static Boolean      hasToLog     = null;
    private static Boolean      proxyVcToLog = false;

    /**
     * Initialize factory.
     *
     * @param mustLog indicate if must initiate Slf4j log
     */
    @SuppressWarnings("unchecked")
    public static void init(boolean mustLog) {
        if ((hasToLog == null || hasToLog != mustLog) && mustLog) {
            synchronized (LoggerFactory.class) {
                if (hasToLog == null || hasToLog != mustLog) {
                    try {
                        Class.forName("org.slf4j.LoggerFactory");
                        hasToLog = Boolean.TRUE;
                    } catch (ClassNotFoundException classNotFound) {
                        System.out.println("Logging cannot be activated, missing slf4j dependency");
                        hasToLog = Boolean.FALSE;
                    }
                }
            }
        }
    }

    /**
     * Initialize logger.
     *
     * @param clazz initiator class
     * @return logger
     */
    public static Logger getLogger(Class<?> clazz) {
        if (hasToLog != null && hasToLog) {
            return new Slf4JLogger(org.slf4j.LoggerFactory.getLogger(clazz));
        } else {
            return NO_LOGGER;
        }
    }

    public static Logger getLogger(String name) {
        if (hasToLog != null && hasToLog) {
            return new Slf4JLogger(org.slf4j.LoggerFactory.getLogger(name));
        } else {
            return NO_LOGGER;
        }
    }

    public static void initProxyVc(boolean mustLog) {
        proxyVcToLog = mustLog;
    }

    /**
     * Initialize logger.
     *
     * @param clazz initiator class
     * @return logger
     */
    public static Logger getLoggerProxy(Class<?> clazz) {
        if (proxyVcToLog) {
            try {
                Class.forName("org.slf4j.LoggerFactory");
                return new Slf4JLogger(org.slf4j.LoggerFactory.getLogger(clazz));
            } catch (ClassNotFoundException classNotFound) {
                proxyVcToLog = false;
                return NO_LOGGER;
            }
        } else {
            return NO_LOGGER;
        }
    }
}
